S class

Implemented types
Implementers

Constructors

S()
const

Properties

copyButtonLabel → String
Label for "copy" edit buttons and menu items.
no setterinherited
cutButtonLabel → String
Label for "cut" edit buttons and menu items.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lookUpButtonLabel → String
Label for "look up" edit buttons and menu items.
no setterinherited
noResultsFound → String
The semantics label used for RawAutocomplete when the options list goes from non-empty to empty.
no setterinherited
pasteButtonLabel → String
Label for "paste" edit buttons and menu items.
no setterinherited
radioButtonUnselectedLabel → String
The accessibility hint for an unselected radio button.
no setterinherited
reorderItemDown → String
The semantics label used for SliverReorderableList to reorder an item in the list one space down the list.
no setterinherited
reorderItemLeft → String
The semantics label used for SliverReorderableList to reorder an item in the list one space left in the list.
no setterinherited
reorderItemRight → String
The semantics label used for SliverReorderableList to reorder an item in the list one space right in the list.
no setterinherited
reorderItemToEnd → String
The semantics label used for SliverReorderableList to reorder an item in the list to the end of the list.
no setterinherited
reorderItemToStart → String
The semantics label used for SliverReorderableList to reorder an item in the list to the start of the list.
no setterinherited
reorderItemUp → String
The semantics label used for SliverReorderableList to reorder an item in the list one space up the list.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchResultsFound → String
The semantics label used for RawAutocomplete when the options list goes from empty to non-empty.
no setterinherited
searchWebButtonLabel → String
Label for "search web" edit buttons and menu items.
no setterinherited
selectAllButtonLabel → String
Label for "select all" edit buttons and menu items.
no setterinherited
shareButtonLabel → String
Label for "share" edit buttons and menu items.
no setterinherited
textDirection → TextDirection
The reading direction for text in this locale.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → S
The WidgetsLocalizations from the closest Localizations instance that encloses the given context.
override